from __future__ import absolute_import, unicode_literals


class APIField(object):
    def __init__(self, name, serializer=None):
        self.name = name
        self.serializer = serializer

    def __hash__(self):
        return hash(self.name)

    def __repr__(self):
        return '<APIField {}>'.format(self.name)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-08 23:51
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0018_remove_rendition_filter'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Filter',
        ),
    ]



from __future__ import absolute_import, unicode_literals

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

# A setting that can be used in foreign key declarations
AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
# Two additional settings that are useful in South migrations when
# specifying the user model in the FakeORM
try:
    AUTH_USER_APP_LABEL, AUTH_USER_MODEL_NAME = AUTH_USER_MODEL.rsplit('.', 1)
except ValueError:
    raise ImproperlyConfigured("AUTH_USER_MODEL must be of the form"
                               " 'app_label.model_name'")
